Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1196)

Unified Diff: chrome/browser/extensions/chrome_app_api_browsertest.cc

Issue 8786004: Revert "Restrict extension features based on the extension type." (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/extensions/extension_prefs.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/extensions/chrome_app_api_browsertest.cc
diff --git a/chrome/browser/extensions/chrome_app_api_browsertest.cc b/chrome/browser/extensions/chrome_app_api_browsertest.cc
index 738afe1969af9f6c5068299eb3ec072ac2b1518c..0f5219e081f81995076c9673f0e87820d784757f 100644
--- a/chrome/browser/extensions/chrome_app_api_browsertest.cc
+++ b/chrome/browser/extensions/chrome_app_api_browsertest.cc
@@ -13,7 +13,6 @@
#include "chrome/browser/ui/browser.h"
#include "chrome/common/chrome_switches.h"
#include "chrome/common/extensions/extension.h"
-#include "chrome/common/extensions/manifest.h"
#include "chrome/test/base/ui_test_utils.h"
#include "content/browser/tab_contents/tab_contents.h"
#include "googleurl/src/gurl.h"
@@ -99,10 +98,10 @@ IN_PROC_BROWSER_TEST_F(ChromeAppAPITest, IsInstalled) {
scoped_ptr<DictionaryValue> app_details(
static_cast<DictionaryValue*>(
base::JSONReader::Read(result, false /* allow trailing comma */)));
// extension->manifest() does not contain the id.
app_details->Remove("id", NULL);
EXPECT_TRUE(app_details.get());
- EXPECT_TRUE(app_details->Equals(extension->manifest()->value()));
+ EXPECT_TRUE(app_details->Equals(extension->manifest_value()));
// Try to change app.isInstalled. Should silently fail, so
// that isInstalled should have the initial value.
@@ -178,8 +177,8 @@ IN_PROC_BROWSER_TEST_F(ChromeAppAPITest, GetDetailsForFrame) {
scoped_ptr<DictionaryValue> app_details(
static_cast<DictionaryValue*>(
base::JSONReader::Read(json, false /* allow trailing comma */)));
// extension->manifest() does not contain the id.
app_details->Remove("id", NULL);
EXPECT_TRUE(app_details.get());
- EXPECT_TRUE(app_details->Equals(extension->manifest()->value()));
+ EXPECT_TRUE(app_details->Equals(extension->manifest_value()));
}
« no previous file with comments | « no previous file | chrome/browser/extensions/extension_prefs.cc » ('j') | no next file with comments »
@@ -99,10 +98,10 @@ IN_PROC_BROWSER_TEST_F(ChromeAppAPITest, IsInstalled) {
static_cast<DictionaryValue*>(
base::JSONReader::Read(result, false /* allow trailing comma */)));
- // extension->manifest() does not contain the id.
+ // extension->manifest_value() does not contain the id.
app_details->Remove("id", NULL);
EXPECT_TRUE(app_details.get());
@@ -178,8 +177,8 @@ IN_PROC_BROWSER_TEST_F(ChromeAppAPITest, GetDetailsForFrame) {
static_cast<DictionaryValue*>(
base::JSONReader::Read(json, false /* allow trailing comma */)));
- // extension->manifest() does not contain the id.
+ // extension->manifest_value() does not contain the id.
app_details->Remove("id", NULL);
EXPECT_TRUE(app_details.get());

Powered by Google App Engine
This is Rietveld 408576698